@@ -2,6 +2,7 @@ import os
 import re
 import glob
 import logging
+import glob
 from .snapshot_release import snapshot_release_publication
 
 logging.basicConfig(level=logging.DEBUG)
@@ -9,15 +10,40 @@ logger = logging.getLogger(__name__)
 
 SNAPSHOT_TAG_SUFFIX = "+dev"
 
-
 def python_get_version():
+    version = python_get_version_from_init()
+    if not version:
+        version = python_get_version_from_setup()
+    return version
+
+
+def python_get_version_from_setup():
     setup_path = os.path.join(os.environ.get('GITHUB_WORKSPACE'), 'setup.py')
     prog = re.compile("version=.*")
-    with open(setup_path, 'r') as f:
-        for line in f:
-            line = line.strip()
-            if prog.match(line):
-                return line[9:-2]
+    try:
+        with open(setup_path, 'r') as f:
+            for line in f:
+                line = line.strip()
+                if prog.match(line):
+                    version = line[9:-2]
+                    logger.info("version {version}")
+                    return version
+        return None
+    except FileNotFoundError:
+        return None
+
+def python_get_version_from_init():
+    init_path_pattern =  os.path.join(os.environ.get('GITHUB_WORKSPACE'), "*", "__init__.py")
+    init_path = glob.glob(init_path_pattern)[0]
+    try:
+        with open(init_path) as fi:
+            result = re.search(r'__version__\s*=\s*[\'"]([^\'"]*)[\'"]', fi.read())
+            if result:
+                return result.group(1)
+            else:
+                return None
+    except FileNotFoundError:
+        return None
 
 
 def python_upload_assets(repo_name, tag_name, release):
